==> lalinference-2.0.3.tar.xz: lalinference-2.0.3/lib/LALInferenceVCSInfoHeader.h <==
/*
 * Copyright (C) 2014, 2016 Karl Wette
 * Copyright (C) 2009-2013 Adam Mercer
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with with program; see the file COPYING. If not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */

/*
 * LALInferenceVCSInfo.h - LALInference VCS Information Header
 */

/** \cond DONT_DOXYGEN */

#ifndef _LALINFERENCEVCSINFOHEADER_H
#define _LALINFERENCEVCSINFOHEADER_H

#include <lal/LALVCSInfoType.h>
#include <lal/LALInferenceVCSInfo.h>
#include <lal/LALInferenceConfig.h>

#ifdef __cplusplus
extern "C" {
#endif

/* VCS information */
#define LALINFERENCE_VCS_ID "88aec4acab9906814543426584fc6f326a91adaf"
#define LALINFERENCE_VCS_DATE "2020-08-7 16:22:37 +0000"
#define LALINFERENCE_VCS_BRANCH "None"
#define LALINFERENCE_VCS_TAG "lalinference-v2.0.3"
#define LALINFERENCE_VCS_AUTHOR "Adam Mercer <adam.mercer@ligo.org>"
#define LALINFERENCE_VCS_COMMITTER "Adam Mercer <ramercer@gmail.com>"
#define LALINFERENCE_VCS_CLEAN "CLEAN"
#define LALINFERENCE_VCS_STATUS "CLEAN: All modifications committed"

#if LALINFERENCE_VERSION_DEVEL != 0
/* VCS header/library mismatch link check function */
#define LALINFERENCE_VCS_LINK_CHECK LALINFERENCE_CLEAN_88aec4acab9906814543426584fc6f326a91adaf_VCS_HEADER_LIBRARY_MISMATCH
void LALINFERENCE_VCS_LINK_CHECK(void);
#endif

#ifdef __cplusplus
}
#endif

#endif /* _LALINFERENCEVCSINFOHEADER_H */

/** \endcond */

==> lalinference-4.1.1.tar.xz: lalinference-4.1.1/lib/LALInferenceVCSInfoHeader.h <==
/*
 * Copyright (C) 2014, 2016 Karl Wette
 * Copyright (C) 2009-2013 Adam Mercer
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with with program; see the file COPYING. If not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301 USA
 */

/*
 * LALInferenceVCSInfo.h - LALInference VCS Information Header
 */

/** \cond DONT_DOXYGEN */

#ifndef _LALINFERENCEVCSINFOHEADER_H
#define _LALINFERENCEVCSINFOHEADER_H

#include <lal/LALVCSInfoType.h>
#include <lal/LALInferenceVCSInfo.h>
#include <lal/LALInferenceConfig.h>

#ifdef __cplusplus
extern "C" {
#endif

/* VCS information */
#define LALINFERENCE_VCS_ID "60eb383a568bfe75a63e22807fd640a3e396f1f5"
#define LALINFERENCE_VCS_DATE "2022-09-6 08:24:17 +0000"
#define LALINFERENCE_VCS_BRANCH "None"
#define LALINFERENCE_VCS_TAG "lalinference-v4.1.1"
#define LALINFERENCE_VCS_AUTHOR "Adam Mercer <adam.mercer@ligo.org>"
#define LALINFERENCE_VCS_COMMITTER "Adam Mercer <adam.mercer@ligo.org>"
#define LALINFERENCE_VCS_CLEAN "CLEAN"
#define LALINFERENCE_VCS_STATUS "CLEAN: All modifications committed"

#if LALINFERENCE_VERSION_DEVEL != 0
/* VCS header/library mismatch link check function */
#define LALINFERENCE_VCS_LINK_CHECK LALINFERENCE_CLEAN_60eb383a568bfe75a63e22807fd640a3e396f1f5_VCS_HEADER_LIBRARY_MISMATCH
void LALINFERENCE_VCS_LINK_CHECK(void);
#endif

#ifdef __cplusplus
}
#endif

#endif /* _LALINFERENCEVCSINFOHEADER_H */

/** \endcond */
